@@ -23,6 +23,9 @@ typedef unsigned long long _u64;
 
 #include <netinet/in.h>
 #include <termios.h>
+#ifdef OPENBSD
+# include <util.h>
+#endif
 #include "osport.h"
 #include "scheduler.h"
 #include "misc.h"
@@ -37,7 +40,7 @@ typedef unsigned long long _u64;
 #define CONTROL_PIPE "/var/run/xl2tpd/l2tp-control"
 
 #define BINARY "xl2tpd"
-#define SERVER_VERSION "xl2tpd-1.2.0"
+#define SERVER_VERSION "xl2tpd-1.2.4"
 #define VENDOR_NAME "xelerance.com"
 #ifndef PPPD
 #define PPPD		"/usr/sbin/pppd"
